// Copyright Melody 2023. Licensed under the EUPL-1.2 or later

use tokio::fs::File;

mod sqlite;
mod postgres;

pub type MessageID = i64;
pub type MediaID = i64;


pub trait StorageAccess {
    fn store_message<E>(user: &str, message: &str) -> Result<MediaID, E>;
    fn get_message<E>(user: &str, id: &MessageID) -> Result<String, E>;
    fn delete_message<T, E>(id: &MessageID) -> Result<T, E>;
    fn edit_message<T, E>(id: &MessageID, message: &str) -> Result<T, E>;

    fn store_media<E>(f: &File, nsfw: bool, alt_text: Option<&str>) -> Result<MediaID, E>;
    fn get_media<E>(id: &MediaID) -> Result<(File, bool, Option<String>), E>;
    fn delete_media<T, E>(id: &MediaID) -> Result<T, E>;
    // No edit media because how? Editing media in a message replaces the media, not edits it
}
